// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef STD_SRVS__SRV__TRIGGER_HPP_
#define STD_SRVS__SRV__TRIGGER_HPP_

#include "std_srvs/srv/detail/trigger__struct.hpp"
#include "std_srvs/srv/detail/trigger__builder.hpp"
#include "std_srvs/srv/detail/trigger__traits.hpp"

#endif  // STD_SRVS__SRV__TRIGGER_HPP_
